@@ -287,10 +287,10 @@ class TranslationServiceAsyncClient:
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             target_language_code (:class:`str`):
-                Required. The BCP-47 language code to
-                use for translation of the input text,
-                set to one of the language codes listed
-                in Language Support.
+                Required. The ISO-639 language code
+                to use for translation of the input
+                text, set to one of the language codes
+                listed in Language Support.
 
                 This corresponds to the ``target_language_code`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -298,8 +298,8 @@ class TranslationServiceAsyncClient:
             contents (:class:`MutableSequence[str]`):
                 Required. The content of the input in
                 string format. We recommend the total
-                content be less than 30k codepoints. The
-                max length of this field is 1024.
+                content be less than 30,000 codepoints.
+                The max length of this field is 1024.
                 Use BatchTranslateText for larger text.
 
                 This corresponds to the ``contents`` field
@@ -337,8 +337,8 @@ class TranslationServiceAsyncClient:
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             source_language_code (:class:`str`):
-                Optional. The BCP-47 language code of
-                the input text if known, for example,
+                Optional. The ISO-639 language code
+                of the input text if known, for example,
                 "en-US" or "sr-Latn". Supported language
                 codes are listed in Language Support. If
                 the source language isn't specified, the
@@ -1027,19 +1027,17 @@ class TranslationServiceAsyncClient:
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             source_language_code (:class:`str`):
-                Required. The BCP-47 language code of
-                the input document if known, for
-                example, "en-US" or "sr-Latn". Supported
-                language codes are listed in Language
-                Support
-                (https://cloud.google.com/translate/docs/languages).
+                Required. The ISO-639 language code of the input
+                document if known, for example, "en-US" or "sr-Latn".
+                Supported language codes are listed in `Language
+                Support <https://cloud.google.com/translate/docs/languages>`__.
 
                 This corresponds to the ``source_language_code`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             target_language_codes (:class:`MutableSequence[str]`):
-                Required. The BCP-47 language code to
-                use for translation of the input
+                Required. The ISO-639 language code
+                to use for translation of the input
                 document. Specify up to 10 language
                 codes here.
 
@@ -1223,7 +1221,7 @@ class TranslationServiceAsyncClient:
 
                 The result type for the operation will be
                 :class:`google.cloud.translate_v3.types.Glossary`
-                Represents a glossary built from user provided data.
+                Represents a glossary built from user-provided data.
 
         """
         # Create or coerce a protobuf request object.
@@ -1461,8 +1459,8 @@ class TranslationServiceAsyncClient:
 
         Returns:
             google.cloud.translate_v3.types.Glossary:
-                Represents a glossary built from user
-                provided data.
+                Represents a glossary built from
+                user-provided data.
 
         """
         # Create or coerce a protobuf request object.
